#include <sys/time.h>
#include <time.h>
#include <sys/types.h>
#include <unistd.h>
#include <glib.h>

#ifndef HAVE_SCHED_H
#define HAVE_SCHED_H
#endif

#ifdef HAVE_SCHED_H
#include <sched.h>
#endif

#ifndef HAVE_NANOSLEEP
#define HAVE_NANOSLEEP
#endif

#ifndef HAVE_SCHED_SETSCHEDULER
#define HAVE_SCHED_SETSCHEDULER
#endif


gboolean xmms_check_realtime_priority(void)
{
#ifdef HAVE_SCHED_SETSCHEDULER
#ifdef __FreeBSD__
	/*
	 * Check if priority scheduling is enabled in the kernel
	 * before sched_getschedule() (so that we don't get
	 * non-present syscall warnings in kernel log).
	 */
	int val = 0, len;

	len = sizeof(val);
	sysctlbyname("p1003_1b.priority_scheduling", &val, &len, NULL, 0);
	if ( !val )
		return FALSE;
#endif
	if (sched_getscheduler(0) == SCHED_RR)
		return TRUE;
	else
#endif
		return FALSE;
}




void xmms_usleep(gint usec)
{
#ifdef HAVE_NANOSLEEP
	struct timespec req;

	req.tv_sec = usec / 1000000;
	usec -= req.tv_sec * 1000000;
	req.tv_nsec = usec * 1000;

	nanosleep(&req, NULL);
#else

	struct timeval tv;
	
	tv.tv_sec = usec / 1000000;
	usec -= tv.tv_sec * 1000000;
	tv.tv_usec = usec;
	select(0, NULL, NULL, NULL, &tv);
#endif
}
